==> migrate_wizard-1.0.19-alpha1.tar.gz: migrate_wizard/src/Form/MigrateWizardMappingForm.php <==
<?php

namespace Drupal\migrate_wizard\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Config\ConfigManager;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Extension\ExtensionList;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\migrate_wizard\MWManageDataService;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure migrate_wizard conection settings for this site.
 */
class MigrateWizardMappingForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected $config;

  /**
   * {@inheritdoc}
   */
  protected $extensionListModule;

  /**
   * {@inheritdoc}
   */
  protected $configManager;

  /**
   * {@inheritdoc}
   */
  protected $entityTypeManager;

  /**
   * {@inheritdoc}
   */
  protected $mwManageDataService;

  /**
   * {@inheritdoc}
   */
  protected $originFormats;

  /**
   * {@inheritdoc}
   */
  public function __construct(ConfigFactoryInterface $configFactory, ExtensionList $extension_list_module, ConfigManager $config_manager, EntityTypeManagerInterface $entity_type_manager, MWManageDataService $mw_manage_data_service) {
    $this->config = $configFactory->getEditable('migrate_wizard.settings');
    $this->extensionListModule = $extension_list_module;
    $this->configManager = $config_manager;
    $this->entityTypeManager = $entity_type_manager;
    $this->mwManageDataService = $mw_manage_data_service;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new self(
      $container->get('config.factory'),
      $container->get('extension.list.module'),
      $container->get('config.manager'),
      $container->get('entity_type.manager'),
      $container->get('migrate_wizard.migrate_wizard_manage_data_service'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'migrate_wizard';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['migrate_wizard_settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $current_config = $this->config->get('origin_formats');
    // Get editor formats from drupal 10.
    $current_formats = $this->entityTypeManager->getStorage('filter_format')->loadMultiple();
    $current_formats_array = [];
    foreach ($current_formats as $current_format) {
      $current_formats_array[$current_format->id()] = $current_format->label();
    }
    $current_formats_array = ['none' => 'Select a field'] + $current_formats_array;
    $this->originFormats = $this->mwManageDataService->getOriginEditorFormats();

    foreach ($this->originFormats as $origin_format) {

      $format = $origin_format['format'];
      $current_formats_value = $current_config[$format] ?? '';

      $form['format'][$format] = [
        '#type' => 'select',
        '#title' => t('Origin Format  @format', ['@format' => $format]),
        '#options' => $current_formats_array,
        '#value' => $current_formats_value,
      ];

    }

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {}

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $user_inputs = $form_state->getUserInput();
    foreach ($this->originFormats as $origin_format) {
      if ($user_inputs[$origin_format['format']] != 'none') {
        $array_config[$origin_format['format']] = $user_inputs[$origin_format['format']];
      }
    }
    $this->config->set('origin_formats', $array_config)->save();
  }

}

==> migrate_wizard-1.0.21-alpha1.tar.gz: migrate_wizard/src/Form/MigrateWizardMappingForm.php <==
<?php

namespace Drupal\migrate_wizard\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Config\ConfigManager;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Extension\ExtensionList;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\migrate_wizard\MWManageDataService;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure migrate_wizard conection settings for this site.
 */
class MigrateWizardMappingForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected $config;

  /**
   * {@inheritdoc}
   */
  protected $extensionListModule;

  /**
   * {@inheritdoc}
   */
  protected $configManager;

  /**
   * {@inheritdoc}
   */
  protected $entityTypeManager;

  /**
   * {@inheritdoc}
   */
  protected $mwManageDataService;

  /**
   * {@inheritdoc}
   */
  protected $originFormats;

  /**
   * {@inheritdoc}
   */
  public function __construct(ConfigFactoryInterface $configFactory, ExtensionList $extension_list_module, ConfigManager $config_manager, EntityTypeManagerInterface $entity_type_manager, MWManageDataService $mw_manage_data_service) {
    $this->config = $configFactory->getEditable('migrate_wizard.settings');
    $this->extensionListModule = $extension_list_module;
    $this->configManager = $config_manager;
    $this->entityTypeManager = $entity_type_manager;
    $this->mwManageDataService = $mw_manage_data_service;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new self(
      $container->get('config.factory'),
      $container->get('extension.list.module'),
      $container->get('config.manager'),
      $container->get('entity_type.manager'),
      $container->get('migrate_wizard.migrate_wizard_manage_data_service'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'migrate_wizard';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['migrate_wizard_settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $current_config = $this->config->get('origin_formats');
    // Get editor formats from drupal 10.
    $current_formats = $this->entityTypeManager->getStorage('filter_format')->loadMultiple();
    $current_formats_array = [];
    foreach ($current_formats as $current_format) {
      $current_formats_array[$current_format->id()] = $current_format->label();
    }
    $current_formats_array = ['none' => 'Select a field'] + $current_formats_array;
    $this->originFormats = $this->mwManageDataService->getOriginEditorFormats();

    foreach ($this->originFormats as $origin_format) {

      $format = $origin_format['format'];
      $current_formats_value = $current_config[$format] ?? '';

      $form['format'][$format] = [
        '#type' => 'select',
        '#title' => t('Origin Format  @format', ['@format' => $format]),
        '#options' => $current_formats_array,
        '#value' => $current_formats_value,
      ];

    }

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {}

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {

    $user_inputs = $form_state->getUserInput();
    foreach ($this->originFormats as $origin_format) {
      if ($user_inputs[$origin_format['format']] != 'none') {
        $array_config[$origin_format['format']] = $user_inputs[$origin_format['format']];
      }
    }
    $this->config->set('origin_formats', $array_config)->save();
  }

}
